@@ -256,6 +256,10 @@ def _makeReply(irc, msg, s,
         # no harm in doing this extra check, in case a plugin is replying
         # across network (as it may happen with '@network command').
         ret.server_tags['+draft/reply'] = msg.server_tags['msgid']
+        if msg.channel and not irc.isChannel(ret.args[0]):
+            # If replying in non-channel to a channel message, use the tag
+            # defined in https://github.com/ircv3/ircv3-specifications/pull/498
+            ret.server_tags["+draft/channel-context"] = msg.channel
     return ret
 
 def error(*args, **kwargs):
@@ -1800,6 +1804,19 @@ class PluginRegexp(Plugin):
     def doPrivmsg(self, irc, msg):
         if msg.isError:
             return
+
+        if 'batch' in msg.server_tags:
+            parent_batches = irc.state.getParentBatches(msg)
+            parent_batch_types = [batch.type for batch in parent_batches]
+            if 'chathistory' in parent_batch_types:
+                # Either sent automatically by the server upon join,
+                # or triggered by a plugin (why?!)
+                # Either way, replying to messages from the history would
+                # look weird, because they may have been sent a while ago,
+                # and we may have already answered them.
+                # (this is the same behavior as in Owner.doPrivmsg)
+                return
+
         proxy = self.Proxy(irc, msg)
         if not msg.addressed:
             for (r, name) in self.unaddressedRes:
