@@ -1,7 +1,7 @@
 ###
 # Copyright (c) 2002-2005, Jeremiah Fincher
 # Copyright (c) 2009,2011, James McCoy
-# Copyright (c) 2010-2021, The Limnoria Contributors
+# Copyright (c) 2010-2022, Valentin Lorentz
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -1152,6 +1152,29 @@ class TestTimeoutQueue(SupyTestCase):
         timeFastForward(1.1)
         self.assertFalse(1 in q)
 
+    def testIter(self):
+        q = TimeoutQueue(1)
+        q.enqueue(1)
+        it1 = iter(q)
+        timeFastForward(0.5)
+        q.enqueue(2)
+        it2 = iter(q)
+        self.assertEqual(next(it1), 1)
+        self.assertEqual(next(it2), 1)
+        self.assertEqual(next(it2), 2)
+        with self.assertRaises(StopIteration):
+            next(it2)
+
+        timeFastForward(0.6)
+        self.assertEqual(next(it1), 2)
+        with self.assertRaises(StopIteration):
+            next(it1)
+
+        it3 = iter(q)
+        self.assertEqual(next(it3), 2)
+        with self.assertRaises(StopIteration):
+            next(it3)
+
     def testReset(self):
         q = TimeoutQueue(10)
         q.enqueue(1)
@@ -1159,6 +1182,31 @@ class TestTimeoutQueue(SupyTestCase):
         q.reset()
         self.assertFalse(1 in q)
 
+    def testClean(self):
+        def iter_and_next(q):
+            next(iter(q))
+
+        def contains(q):
+            42 in q
+
+        for f in (len, repr, list, iter_and_next, contains):
+            print(f)
+            with self.subTest(f=f.__name__):
+                q = TimeoutQueue(1)
+                q.enqueue(1)
+                timeFastForward(0.5)
+                q.enqueue(2)
+
+                self.assertEqual([x for (_, x) in q.queue], [1, 2])
+                f(q)
+                self.assertEqual([x for (_, x) in q.queue], [1, 2])
+
+                timeFastForward(0.6)
+
+                self.assertEqual([x for (_, x) in q.queue], [1, 2])  # not cleaned yet
+                f(q)
+                self.assertEqual([x for (_, x) in q.queue], [2])  # now it is
+
 class TestCacheDict(SupyTestCase):
     def testMaxNeverExceeded(self):
         max = 10
